<?php
/* Copyright (C) 2011-2013      Juanjo Menent	    <jmenent@2byte.es>
 * Copyright (C) 2011-2018      Philippe Grand	    <philippe.grand@atoo-net.com>
 * Copyright (C) 2024			MDW					<mdeweerd@users.noreply.github.com>
 * Copyright (C) 2024       	Frédéric France 	<frederic.france@free.fr>
 * Copyright (C) 2024      		Easya Solutions 	<support@easya.solutions>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

/**
 *	\file       htdocs/suppliercontract/admin/suppliercontract.php
 *	\ingroup    suppliercontract
 *	\brief      Setup page of module Supplier Contracts
 */

// Load Dolibarr environment
//require '../main.inc.php';
// Load Dolibarr environment
$res = 0;
// Try main.inc.php into web root known defined into CONTEXT_DOCUMENT_ROOT (not always defined)
if (!$res && !empty($_SERVER["CONTEXT_DOCUMENT_ROOT"])) {
	$res = @include $_SERVER["CONTEXT_DOCUMENT_ROOT"]."/main.inc.php";
}
// Try main.inc.php into web root detected using web root calculated from SCRIPT_FILENAME
$tmp = empty($_SERVER['SCRIPT_FILENAME']) ? '' : $_SERVER['SCRIPT_FILENAME'];
$tmp2 = realpath(__FILE__);
$i = strlen($tmp) - 1;
$j = strlen($tmp2) - 1;
while ($i > 0 && $j > 0 && isset($tmp[$i]) && isset($tmp2[$j]) && $tmp[$i] == $tmp2[$j]) {
	$i--;
	$j--;
}
if (!$res && $i > 0 && file_exists(substr($tmp, 0, ($i + 1))."/main.inc.php")) {
	$res = @include substr($tmp, 0, ($i + 1))."/main.inc.php";
}
if (!$res && $i > 0 && file_exists(dirname(substr($tmp, 0, ($i + 1)))."/main.inc.php")) {
	$res = @include dirname(substr($tmp, 0, ($i + 1)))."/main.inc.php";
}
// Try main.inc.php using relative path
if (!$res && file_exists("../../main.inc.php")) {
	$res = @include "../../main.inc.php";
}
if (!$res && file_exists("../../../main.inc.php")) {
	$res = @include "../../../main.inc.php";
}
if (!$res) {
	die("Include of main fails");
}
require_once DOL_DOCUMENT_ROOT . '/core/lib/admin.lib.php';
require_once DOL_DOCUMENT_ROOT . '/core/lib/pdf.lib.php';
//require_once DOL_DOCUMENT_ROOT.'/suppliercontract/class/suppliercontract.class.php';
//require_once DOL_DOCUMENT_ROOT.'/core/lib/suppliercontract.lib.php';
dol_include_once('/suppliercontract/class/suppliercontract.class.php');
dol_include_once('/suppliercontract/core/lib/suppliercontract.lib.php');
dol_include_once('/suppliercontract/core/lib/opendsi_common.lib.php');

// Load translation files required by the page
$langs->loadLangs(array("admin", "errors", "suppliercontracts@suppliercontract", "opendsi@suppliercontract"));

if (!$user->admin) {
	accessforbidden();
}

$action = GETPOST('action', 'aZ09');
$value = GETPOST('value', 'alpha');
$modulepart = GETPOST('modulepart', 'aZ09');    // Used by actions_setmoduleoptions.inc.php

$label = GETPOST('label', 'alpha');
$scandir = GETPOST('scan_dir', 'alpha');
$type = 'suppliercontract';

if (!getDolGlobalString('SUPPLIERCONTRACT_ADDON')) {
	$conf->global->SUPPLIERCONTRACT_ADDON = 'mod_suppliercontract_serpis';
}


/*
 * Actions
 */

include DOL_DOCUMENT_ROOT . '/core/actions_setmoduleoptions.inc.php';

$error = 0;

// Report to htdocs/core/class/conf.class.php
//if (isset($this->suppliercontract)) {
//	$this->suppliercontract->services = new stdClass();
//	$this->suppliercontract->services->inactifs = new stdClass();
//	$this->suppliercontract->services->expires = new stdClass();
//	$this->suppliercontract->services->inactifs->warning_delay = (isset($this->global->MAIN_DELAY_NOT_ACTIVATED_SUPPLIER_SERVICES) ? (int) $this->global->MAIN_DELAY_NOT_ACTIVATED_SUPPLIER_SERVICES : 0) * 86400;
//	$this->suppliercontract->services->expires->warning_delay = (isset($this->global->MAIN_DELAY_RUNNING_SUPPLIER_SERVICES) ? (int) $this->global->MAIN_DELAY_RUNNING_SUPPLIER_SERVICES : 0) * 86400;
//}

// Define list of managed delays
// Report to htdocs/admin/delais.php
$modules = array(
	'suppliercontract' => array(
		array(
			'code' => 'MAIN_DELAY_NOT_ACTIVATED_SUPPLIER_SERVICES',
			'img' => 'service'
		),
		array(
			'code' => 'MAIN_DELAY_RUNNING_SUPPLIER_SERVICES',
			'img' => 'service'
		)
	),
);

if ($action == 'set_delay') {
	foreach ($modules as $module => $delays) {
		if (isModEnabled($module)) {
			foreach ($delays as $delay) {
				if (GETPOST($delay['code']) != '') {
					dolibarr_set_const($db, $delay['code'], GETPOST($delay['code']), 'chaine', 0, '', $conf->entity);
				}
			}
		}
	}

	setEventMessages($langs->trans("SetupSaved"), null, 'mesgs');
} elseif ($action == 'updateMask') {
	$maskconst = GETPOST('maskconstsuppliercontract', 'aZ09');
	$maskvalue = GETPOST('masksuppliercontract', 'alpha');
	$res = 0;
	if ($maskconst && preg_match('/_MASK$/', $maskconst)) {
		$res = dolibarr_set_const($db, $maskconst, $maskvalue, 'chaine', 0, '', $conf->entity);
	}

	if (!($res > 0)) {
		$error++;
	}

	if (!$error) {
		setEventMessages($langs->trans("SetupSaved"), null, 'mesgs');
	} else {
		setEventMessages($langs->trans("Error"), null, 'errors');
	}
} elseif ($action == 'specimen') { // For supplier contract
	$modele = GETPOST('module', 'alpha');

	$suppliercontract = new SupplierContract($db);
	$suppliercontract->initAsSpecimen();

	// Search template files
	$file = '';
	$classname = '';
	$dirmodels = array_merge(array('/'), (array)$conf->modules_parts['models']);
	foreach ($dirmodels as $reldir) {
		$file = dol_buildpath($reldir . "core/modules/suppliercontract/doc/pdf_" . $modele . ".modules.php", 0);
		if (file_exists($file)) {
			$classname = "pdf_" . $modele;
			break;
		}
	}

	if ($classname !== '') {
		require_once $file;

		$module = new $classname($db);
		'@phan-var-force ModelePDFSupplierContract $module';

		/** @var ModelePDFSupplierContract $module */
		if ($module->write_file($suppliercontract, $langs) > 0) {
			header("Location: " . DOL_URL_ROOT . "/document.php?modulepart=suppliercontract&file=SPECIMEN.pdf");
			return;
		} else {
			setEventMessages($module->error, $module->errors, 'errors');
			dol_syslog($module->error, LOG_ERR);
		}
	} else {
		setEventMessages($langs->trans("ErrorModuleNotFound"), null, 'errors');
		dol_syslog($langs->trans("ErrorModuleNotFound"), LOG_ERR);
	}
} elseif ($action == 'set') {
	// Activate a model
	$ret = addDocumentModel($value, $type, $label, $scandir);
} elseif ($action == 'del') {
	$ret = delDocumentModel($value, $type);
	if ($ret > 0) {
		if ($conf->global->SUPPLIERCONTRACT_ADDON_PDF == "$value") {
			dolibarr_del_const($db, 'SUPPLIERCONTRACT_ADDON_PDF', $conf->entity);
		}
	}
} elseif ($action == 'setdoc') {
	// Set default model
	if (dolibarr_set_const($db, "SUPPLIERCONTRACT_ADDON_PDF", $value, 'chaine', 0, '', $conf->entity)) {
		// La constante qui a ete lue en avant du nouveau set
		// on passe donc par une variable pour avoir un affichage coherent
		$conf->global->SUPPLIERCONTRACT_ADDON_PDF = $value;
	}

	// On active le modele
	$ret = delDocumentModel($value, $type);
	if ($ret > 0) {
		$ret = addDocumentModel($value, $type, $label, $scandir);
	}
} elseif ($action == 'unsetdoc') {
	dolibarr_del_const($db, "SUPPLIERCONTRACT_ADDON_PDF", $conf->entity);
} elseif ($action == 'setmod') {
	// TODO Verify si the chosen numbering module can be activated by
	// the method call canBeActivated

	dolibarr_set_const($db, "SUPPLIERCONTRACT_ADDON", $value, 'chaine', 0, '', $conf->entity);
} elseif ($action == 'set_other') {
	$freetext = GETPOST('SUPPLIERCONTRACT_FREE_TEXT', 'restricthtml'); // No alpha here, we want exact string
	$res1 = dolibarr_set_const($db, "SUPPLIERCONTRACT_FREE_TEXT", $freetext, 'chaine', 0, '', $conf->entity);

	$draft = GETPOST('SUPPLIERCONTRACT_DRAFT_WATERMARK', 'alpha');
	$res2 = dolibarr_set_const($db, "SUPPLIERCONTRACT_DRAFT_WATERMARK", trim($draft), 'chaine', 0, '', $conf->entity);

	$value = GETPOST('activate_hideClosedServiceByDefault', 'alpha');
	$res3 = dolibarr_set_const($db, "SUPPLIERCONTRACT_HIDE_CLOSED_SERVICES_BY_DEFAULT", $value, 'chaine', 0, '', $conf->entity);

	if (!($res1 > 0) || !($res2 > 0) || !($res3 > 0)) {
		$error++;
	}

	if (!$error) {
		setEventMessages($langs->trans("SetupSaved"), null, 'mesgs');
	} else {
		setEventMessages($langs->trans("Error"), null, 'errors');
	}
} elseif (preg_match('/set_(.*)/', $action, $reg)) {
	$code = $reg[1];
	$value = (GETPOST($code) ? GETPOST($code) : 1);

	$res = dolibarr_set_const($db, $code, $value, 'chaine', 0, '', $conf->entity);
	if (!($res > 0)) {
		$error++;
	}

	if ($error) {
		setEventMessages($langs->trans('Error'), null, 'errors');
	} else {
		setEventMessages($langs->trans('SetupSaved'), null, 'mesgs');
		header("Location: " . $_SERVER["PHP_SELF"]);
		exit();
	}
} elseif (preg_match('/del_(.*)/', $action, $reg)) {
	$code = $reg[1];
	$res = dolibarr_del_const($db, $code, $conf->entity);

	if (!($res > 0)) {
		$error++;
	}

	if ($error) {
		setEventMessages($langs->trans('Error'), null, 'errors');
	} else {
		setEventMessages($langs->trans('SetupSaved'), null, 'mesgs');
		header("Location: " . $_SERVER["PHP_SELF"]);
		exit();
	}
}


/*
 * View
 */

$dirmodels = array_merge(array('/'), (array)$conf->modules_parts['models']);
$help_url = 'EN:Module_SupplierContracts|FR:Module_ContratsFournisseur|ES:Contratos_de_proveedor';

llxHeader('', '', $help_url, '', 0, 0, '', '', '', 'mod-admin page-suppliercontract');

$form = new Form($db);

$linkback = '<a href="' . DOL_URL_ROOT . '/admin/modules.php?restore_lastsearch_values=1">' . $langs->trans("BackToModuleList") . '</a>';
print load_fiche_titre($langs->trans("SupplierContractsSetup"), $linkback, 'title_setup');

$head = supplierContractAdminPrepareHead();

print dol_get_fiche_head($head, 'suppliercontract', $langs->trans("SupplierContracts"), -1, 'easya@suppliercontract');

/*
 * Supplier Contracts Numbering model
 */

print load_fiche_titre($langs->trans("SupplierContractsNumberingModules"), '', '');

print '<div class="div-table-responsive-no-min">';
print '<table class="noborder centpercent">';
print '<tr class="liste_titre">';
print '<td width="100">' . $langs->trans("Name") . '</td>';
print '<td>' . $langs->trans("Description") . '</td>';
print '<td>' . $langs->trans("Example") . '</td>';
print '<td class="center" width="60">' . $langs->trans("Status") . '</td>';
print '<td class="center" width="16">' . $langs->trans("ShortInfo") . '</td>';
print "</tr>\n";

clearstatcache();

foreach ($dirmodels as $reldir) {
	$dir = dol_buildpath($reldir . "core/modules/suppliercontract/");

	if (is_dir($dir)) {
		$handle = opendir($dir);
		if (is_resource($handle)) {
			while (($file = readdir($handle)) !== false) {
				if (substr($file, 0, 21) == 'mod_suppliercontract_' && substr($file, dol_strlen($file) - 3, 3) == 'php') {
					$file = substr($file, 0, dol_strlen($file) - 4);

					require_once $dir . $file . '.php';
					/** @var ModelNumRefSupplierContracts $module */
					$module = new $file($db);

					'@phan-var-force ModelNumRefSupplierContracts $module';

					// Show modules according to features level
					if ($module->version == 'development' && getDolGlobalInt('MAIN_FEATURES_LEVEL') < 2) {
						continue;
					}
					if ($module->version == 'experimental' && getDolGlobalInt('MAIN_FEATURES_LEVEL') < 1) {
						continue;
					}

					if ($module->isEnabled()) {
						print '<tr class="oddeven"><td>' . $module->name . "</td><td>\n";
						print $module->info($langs);
						print '</td>';

						// Show example of numbering model
						print '<td class="nowrap">';
						$tmp = $module->getExample();
						if (preg_match('/^Error/', $tmp)) {
							$langs->load("errors");
							print '<div class="error">' . $langs->trans($tmp) . '</div>';
						} elseif ($tmp == 'NotConfigured') {
							print '<span class="opacitymedium">' . $langs->trans($tmp) . '</span>';
						} else {
							print $tmp;
						}
						print '</td>' . "\n";

						print '<td class="center">';
						if ($conf->global->SUPPLIERCONTRACT_ADDON == "$file") {
							print img_picto($langs->trans("Activated"), 'switch_on');
						} else {
							print '<a class="reposition" href="' . $_SERVER["PHP_SELF"] . '?action=setmod&token=' . newToken() . '&value=' . urlencode($file) . '">';
							print img_picto($langs->trans("Disabled"), 'switch_off');
							print '</a>';
						}
						print '</td>';

						$suppliercontract = new SupplierContract($db);
						$suppliercontract->initAsSpecimen();

						// Info
						$htmltooltip = '';
						$htmltooltip .= '' . $langs->trans("Version") . ': <b>' . $module->getVersion() . '</b><br>';
						$nextval = $module->getNextValue($mysoc, $suppliercontract);
						if ("$nextval" != $langs->trans("NotAvailable")) {  // Keep " on nextval
							$htmltooltip .= '' . $langs->trans("NextValue") . ': ';
							if ($nextval) {
								if (preg_match('/^Error/', $nextval) || $nextval == 'NotConfigured') {
									$nextval = $langs->trans($nextval);
								}
								$htmltooltip .= $nextval . '<br>';
							} else {
								$htmltooltip .= $langs->trans($module->error) . '<br>';
							}
						}

						print '<td class="center">';
						print $form->textwithpicto('', $htmltooltip, 1, 0);
						print '</td>';

						print '</tr>';
					}
				}
			}
			closedir($handle);
		}
	}
}

print '</table></div><br>';

/*
 *  Documents models for Supplier Contracts
 */

print load_fiche_titre($langs->trans("TemplatePDFSupplierContracts"), '', '');

// Defini tableau def des modeles
$def = array();
$sql = "SELECT nom";
$sql .= " FROM " . MAIN_DB_PREFIX . "document_model";
$sql .= " WHERE type = '" . $db->escape($type) . "'";
$sql .= " AND entity = " . $conf->entity;
$resql = $db->query($sql);
if ($resql) {
	$i = 0;
	$num_rows = $db->num_rows($resql);
	while ($i < $num_rows) {
		$array = $db->fetch_array($resql);
		if (is_array($array)) {
			array_push($def, $array[0]);
		}
		$i++;
	}
} else {
	dol_print_error($db);
}


print '<div class="div-table-responsive-no-min">';
print '<table class="noborder centpercent">';
print '<tr class="liste_titre">';
print '<td>' . $langs->trans("Name") . '</td>';
print '<td>' . $langs->trans("Description") . '</td>';
print '<td class="center" width="60">' . $langs->trans("Status") . "</td>\n";
print '<td class="center" width="60">' . $langs->trans("Default") . "</td>\n";
print '<td class="center" width="80">' . $langs->trans("ShortInfo") . '</td>';
print '<td class="center" width="80">' . $langs->trans("Preview") . '</td>';
print "</tr>\n";

clearstatcache();

foreach ($dirmodels as $reldir) {
	foreach (array('', '/doc') as $valdir) {
		$realpath = $reldir . "core/modules/suppliercontract" . $valdir;
		$dir = dol_buildpath($realpath);

		if (is_dir($dir)) {
			$handle = opendir($dir);
			if (is_resource($handle)) {
				$filelist = array();
				while (($file = readdir($handle)) !== false) {
					$filelist[] = $file;
				}
				closedir($handle);
				arsort($filelist);

				foreach ($filelist as $file) {
					if (preg_match('/\.modules\.php$/i', $file) && preg_match('/^(pdf_|doc_)/', $file)) {
						if (file_exists($dir . '/' . $file)) {
							$name = substr($file, 4, dol_strlen($file) - 16);
							$classname = substr($file, 0, dol_strlen($file) - 12);

							require_once $dir . '/' . $file;
							/** @var ModelePDFSupplierContract $module */
							$module = new $classname($db);

							'@phan-var-force ModelePDFSupplierContract $module';

							$modulequalified = 1;
							if ($module->version == 'development' && getDolGlobalInt('MAIN_FEATURES_LEVEL') < 2) {
								$modulequalified = 0;
							}
							if ($module->version == 'experimental' && getDolGlobalInt('MAIN_FEATURES_LEVEL') < 1) {
								$modulequalified = 0;
							}

							if ($modulequalified) {
								print '<tr class="oddeven"><td width="100">';
								print(empty($module->name) ? $name : $module->name);
								print "</td><td>\n";
								if (method_exists($module, 'info')) {
									print $module->info($langs);  // @phan-suppress-current-line PhanUndeclaredMethod
								} else {
									print $module->description;
								}
								print '</td>';

								// Active
								if (in_array($name, $def)) {
									print '<td class="center">' . "\n";
									print '<a class="reposition" href="' . $_SERVER["PHP_SELF"] . '?action=del&token=' . newToken() . '&value=' . urlencode($name) . '">';
									print img_picto($langs->trans("Enabled"), 'switch_on');
									print '</a>';
									print '</td>';
								} else {
									print '<td class="center">' . "\n";
									print '<a class="reposition" href="' . $_SERVER["PHP_SELF"] . '?action=set&token=' . newToken() . '&value=' . urlencode($name) . '&scan_dir=' . urlencode($module->scandir) . '&label=' . urlencode($module->name) . '">' . img_picto($langs->trans("Disabled"), 'switch_off') . '</a>';
									print "</td>";
								}

								// Default
								print '<td class="center">';
								if (getDolGlobalString('SUPPLIERCONTRACT_ADDON_PDF') == $name) {
									print '<a class="reposition" href="' . $_SERVER["PHP_SELF"] . '?action=unsetdoc&token=' . newToken() . '&value=' . urlencode($name) . '&scan_dir=' . urlencode($module->scandir) . '&label=' . urlencode($module->name) . '&type=order_supplier" alt="' . $langs->trans("Disable") . '">' . img_picto($langs->trans("Enabled"), 'on') . '</a>';
								} else {
									print '<a class="reposition" href="' . $_SERVER["PHP_SELF"] . '?action=setdoc&token=' . newToken() . '&value=' . urlencode($name) . '&scan_dir=' . urlencode($module->scandir) . '&label=' . urlencode($module->name) . '" alt="' . $langs->trans("Default") . '">' . img_picto($langs->trans("Disabled"), 'off') . '</a>';
								}
								print '</td>';

								// Info
								$htmltooltip = '' . $langs->trans("Name") . ': ' . $module->name;
								$htmltooltip .= '<br>' . $langs->trans("Type") . ': ' . ($module->type ? $module->type : $langs->trans("Unknown"));
								if ($module->type == 'pdf') {
									$htmltooltip .= '<br>' . $langs->trans("Width") . '/' . $langs->trans("Height") . ': ' . $module->page_largeur . '/' . $module->page_hauteur;
								}
								$htmltooltip .= '<br>' . $langs->trans("Path") . ': ' . preg_replace('/^\//', '', $realpath) . '/' . $file;

								$htmltooltip .= '<br><br><u>' . $langs->trans("FeaturesSupported") . ':</u>';
								$htmltooltip .= '<br>' . $langs->trans("Logo") . ': ' . yn($module->option_logo, 1, 1);
								$htmltooltip .= '<br>' . $langs->trans("PaymentMode") . ': ' . yn($module->option_modereg, 1, 1);
								$htmltooltip .= '<br>' . $langs->trans("PaymentConditions") . ': ' . yn($module->option_condreg, 1, 1);
								$htmltooltip .= '<br>' . $langs->trans("MultiLanguage") . ': ' . yn($module->option_multilang, 1, 1);
								$htmltooltip .= '<br>' . $langs->trans("WatermarkOnDraftOrders") . ': ' . yn($module->option_draft_watermark, 1, 1);


								print '<td class="center">';
								print $form->textwithpicto('', $htmltooltip, 1, 0);
								print '</td>';

								// Preview
								print '<td class="center">';
								if ($module->type == 'pdf') {
									print '<a href="' . $_SERVER["PHP_SELF"] . '?action=specimen&module=' . $name . '">' . img_object($langs->trans("Preview"), 'pdf') . '</a>';
								} else {
									print img_object($langs->trans("PreviewNotAvailable"), 'generic');
								}
								print '</td>';

								print "</tr>\n";
							}
						}
					}
				}
			}
		}
	}
}

print '</table>';
print '</div>';
print "<br>";


/*
 * Delays
 *
 */

print '<form action="' . $_SERVER["PHP_SELF"] . '" method="post">';
print '<input type="hidden" name="token" value="' . newToken() . '">';
print '<input type="hidden" name="action" value="set_delay">';

print load_fiche_titre($langs->trans("DelaysOfToleranceBeforeWarning"), '', '');

print '<span class="opacitymedium">'.$langs->transnoentities("DelaysOfToleranceDesc", img_warning('default', '', 'pictowarning nopaddingleft')).'</span>';

print '<div class="div-table-responsive-no-min">';
print '<table class="noborder centpercent">';
print '<tr class="liste_titre">';
print '<td colspan="2">' . $langs->trans("DelaysOfToleranceBeforeWarning") . '</td>';
print '<td class="right">' . $langs->trans("LateWarningAfter") . '</td>';
print "</tr>\n";

foreach ($modules as $module => $delays) {
	if (isModEnabled($module)) {
		foreach ($delays as $delay) {
			$value = getDolGlobalInt($delay['code']);
			print '<tr class="oddeven">';
			print '<td width="20px">' . img_object('', $delay['img']) . '</td>';
			print '<td>' . $langs->trans('Delays_' . $delay['code']) . '</td><td class="nowraponall right">';
			print '<input class="right maxwidth75" type="number" name="' . $delay['code'] . '" value="' . $value . '"> ' . $langs->trans("days") . '</td></tr>';
		}
	}
}

print '</table>';
print '</div>';

print $form->buttonsSaveCancel("Save", '');

print '</form>';


/*
 * Other options
 *
 */

print '<form action="' . $_SERVER["PHP_SELF"] . '" method="post">';
print '<input type="hidden" name="token" value="' . newToken() . '">';
print '<input type="hidden" name="action" value="set_other">';

print load_fiche_titre($langs->trans("OtherOptions"), '', '');

print '<div class="div-table-responsive-no-min">';
print '<table class="noborder centpercent">';
print '<tr class="liste_titre">';
print '<td>' . $langs->trans("Parameter") . '</td>';
print '<td class="right">' . $langs->trans("Value") . '</td>';
print "</tr>\n";

$substitutionarray = pdf_getSubstitutionArray($langs, array('objectamount'), null, 2);
$substitutionarray['__(AnyTranslationKey)__'] = $langs->trans("Translation");
$htmltext = '<i>' . $langs->trans("AvailableVariables") . ':<br>';
foreach ($substitutionarray as $key => $val) {
	$htmltext .= $key . '<br>';
}
$htmltext .= '</i>';

print '<tr class="oddeven"><td colspan="2">';
print $form->textwithpicto($langs->trans("FreeLegalTextOnSupplierContracts"), $langs->trans("AddCRIfTooLong") . '<br><br>' . $htmltext, 1, 'help', '', 0, 2, 'tooltiphelp');
print '<br>';
$variablename = 'SUPPLIERCONTRACT_FREE_TEXT';
if (!getDolGlobalString('PDF_ALLOW_HTML_FOR_FREE_TEXT')) {
	print '<textarea name="' . $variablename . '" class="flat" cols="120">' . getDolGlobalString($variablename) . '</textarea>';
} else {
	include_once DOL_DOCUMENT_ROOT . '/core/class/doleditor.class.php';
	$doleditor = new DolEditor($variablename, getDolGlobalString($variablename), '', 80, 'dolibarr_notes');
	print $doleditor->Create();
}
print '</td></tr>' . "\n";

//Use draft Watermark

print '<tr class="oddeven"><td>';
print $form->textwithpicto($langs->trans("WatermarkOnDraftSupplierContractCards"), $htmltext, 1, 'help', '', 0, 2, 'watermarktooltip') . '<br>';
print '</td><td class="right">';
print '<input class="flat minwidth200" type="text" name="SUPPLIERCONTRACT_DRAFT_WATERMARK" value="' . dol_escape_htmltag(getDolGlobalString('SUPPLIERCONTRACT_DRAFT_WATERMARK')) . '">';
print '</td></tr>' . "\n";

print '<tr class="oddeven">';
print '<td>' . $langs->trans("HideClosedServiceByDefault") . '</td>';
print '<td class="right">';
print $form->selectyesno("activate_hideClosedServiceByDefault", getDolGlobalInt('SUPPLIERCONTRACT_HIDE_CLOSED_SERVICES_BY_DEFAULT', 0), 1);
print '</td>';
print '</tr>';

// Allow external download
print '<tr class="oddeven">';
print '<td>' . $langs->trans("AllowExternalDownload") . '</td>';
print '<td class="right">';
print ajax_constantonoff('SUPPLIERCONTRACT_ALLOW_EXTERNAL_DOWNLOAD', array(), null, 0, 0, 0, 2, 0, 1);
print '</td>';
print '</tr>';
print '</table>';
print '</div>';

print $form->buttonsSaveCancel("Save", '');

print '</form>';

print dol_get_fiche_end();

// End of page
llxFooter();
$db->close();
